This function takes input object and type character to ingest the input object to return the object in the desired class.
.par_screen(type, input, input_id = NULL, out_class = "terra", .window = NULL)character(1). "raster" or "vector".
object. Input object.
character(1). Default is NULL. If NULL, the function will not check the object with an ID column.
character(1). Default is NULL, but should be one of
c("sf", "terra"). Default is "terra".
numeric(4)/SpatExtent/st_bbox object. Loading window.