Skip to contents

This function checks the class of an input object and returns "raster" if it is a raster object, or "vector" if it is a vector object.

Usage

.check_character(input)

Arguments

input

The input object to be checked

Value

A character string indicating the class of the input object ("raster" or "vector")