This function checks the class of an input object and returns "raster" if it is a raster object, or "vector" if it is a vector object.
This function checks the class of an input object and returns "raster" if it is a raster object, or "vector" if it is a vector object.